@@ -54,7 +54,9 @@ NULL
 #'   versions of the \pkg{prioritizr} package, it was known as the
 #'   \code{add_corridor_constraints} function but has since been renamed for
 #'   clarity. It was inspired by the mathematical formulations detailed in
-#'   {\"O}nal and Briers (2006) and Cardeira \emph{et al.} 2010. Please note
+#'   {\"O}nal and Briers (2006) and Cardeira \emph{et al.} 2010. For an
+#'   example that has used these constraints, see Hanson, Fuller,
+#'   and Rhodes (2018). Please note
 #'   that these constraints require the expanded formulation and therefore
 #'   cannot be used with feature data that have negative vales.
 #'   \strong{Please note that adding these constraints to a problem will
@@ -118,6 +120,11 @@ NULL
 #' Cardeira JO, Pinto LS, Cabeza M and Gaston KJ (2010) Species specific
 #' connectivity in reserve-network design using graphs.
 #' \emph{Biological Conservation}, 2: 408--415.
+#'
+#' Hanson JO, Fuller RA, & Rhodes JR (2018) Conventional methods for enhancing
+#' connectivity in conservation planning do not always maintain gene flow.
+#' \emph{Journal of Applied Ecology}, In press:
+#' \url{https://doi.org/10.1111/1365-2664.13315}.
 #' @examples
 #' # load data
 #' data(sim_pu_raster, sim_pu_zones_stack, sim_features, sim_features_zones)
@@ -284,10 +291,10 @@ methods::setMethod("add_feature_contiguity_constraints",
         if (is.data.frame(data[[i]]))
           data[[i]] <- marxan_boundary_data_to_matrix(x, data[[i]])
         # run checks
-        assertthat::assert_that(all(as.vector(data[[i]]) %in% c(0, 1)),
+        assertthat::assert_that(all(data[[i]]@x %in% c(0, 1)),
           ncol(data[[i]]) == nrow(data[[i]]),
           number_of_total_units(x) == ncol(data[[i]]),
-          all(is.finite(as.vector(data[[i]]))), Matrix::isSymmetric(data[[i]]))
+          all(is.finite(data[[i]]@x)), Matrix::isSymmetric(data[[i]]))
       }
       # create list with data
       d <- list(connected_matrices = data)
